@@ -1,13 +1,13 @@
 import pytest
 import river
-import spotPython
-from spotPython.hyperparameters.values import get_core_model_from_name
+import spotpython
+from spotpython.hyperparameters.values import get_core_model_from_name
 
 
 def test_valid_spotpython_model():
     model_name, model_instance = get_core_model_from_name("light.regression.NNLinearRegressor")
     assert model_name == "NNLinearRegressor"
-    assert model_instance == spotPython.light.regression.NNLinearRegressor
+    assert model_instance == spotpython.light.regression.NNLinearRegressor
 
 
 def test_invalid_model_format():
